"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApplicationTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ApplicationTags = ApplicationTags

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[global___ApplicationTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Application = Application

@typing_extensions.final
class AppConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROFILE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STRATEGY_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    HOSTED_CONFIGURATION_VERSION_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    @property
    def configuration_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationProfile]: ...
    @property
    def deployment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Deployment]: ...
    @property
    def deployment_strategy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentStrategy]: ...
    @property
    def environment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Environment]: ...
    @property
    def hosted_configuration_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostedConfigurationVersion]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
        configuration_profile: collections.abc.Iterable[global___ConfigurationProfile] | None = ...,
        deployment: collections.abc.Iterable[global___Deployment] | None = ...,
        deployment_strategy: collections.abc.Iterable[global___DeploymentStrategy] | None = ...,
        environment: collections.abc.Iterable[global___Environment] | None = ...,
        hosted_configuration_version: collections.abc.Iterable[global___HostedConfigurationVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "configuration_profile", b"configuration_profile", "deployment", b"deployment", "deployment_strategy", b"deployment_strategy", "environment", b"environment", "hosted_configuration_version", b"hosted_configuration_version"]) -> None: ...

global___AppConfig = AppConfig

@typing_extensions.final
class ConfigurationProfileValidators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "resource_info", b"resource_info"]) -> None: ...

global___ConfigurationProfileValidators = ConfigurationProfileValidators

@typing_extensions.final
class ConfigurationProfileTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ConfigurationProfileTags = ConfigurationProfileTags

@typing_extensions.final
class ConfigurationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_URI_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    RETRIEVAL_ROLE_ARN_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location_uri: builtins.str
    description: builtins.str
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationProfileValidators]: ...
    retrieval_role_arn: builtins.str
    application_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationProfileTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location_uri: builtins.str = ...,
        description: builtins.str = ...,
        validators: collections.abc.Iterable[global___ConfigurationProfileValidators] | None = ...,
        retrieval_role_arn: builtins.str = ...,
        application_id: builtins.str = ...,
        tags: collections.abc.Iterable[global___ConfigurationProfileTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "description", b"description", "location_uri", b"location_uri", "name", b"name", "resource_info", b"resource_info", "retrieval_role_arn", b"retrieval_role_arn", "tags", b"tags", "validators", b"validators"]) -> None: ...

global___ConfigurationProfile = ConfigurationProfile

@typing_extensions.final
class DeploymentTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentTags = DeploymentTags

@typing_extensions.final
class Deployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STRATEGY_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROFILE_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONFIGURATION_VERSION_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    deployment_strategy_id: builtins.str
    configuration_profile_id: builtins.str
    environment_id: builtins.str
    description: builtins.str
    configuration_version: builtins.str
    application_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentTags]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_strategy_id: builtins.str = ...,
        configuration_profile_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        description: builtins.str = ...,
        configuration_version: builtins.str = ...,
        application_id: builtins.str = ...,
        tags: collections.abc.Iterable[global___DeploymentTags] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "configuration_profile_id", b"configuration_profile_id", "configuration_version", b"configuration_version", "deployment_strategy_id", b"deployment_strategy_id", "description", b"description", "environment_id", b"environment_id", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Deployment = Deployment

@typing_extensions.final
class DeploymentStrategyTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentStrategyTags = DeploymentStrategyTags

@typing_extensions.final
class DeploymentStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPLICATE_TO_FIELD_NUMBER: builtins.int
    GROWTH_TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEPLOYMENT_DURATION_IN_MINUTES_FIELD_NUMBER: builtins.int
    GROWTH_FACTOR_FIELD_NUMBER: builtins.int
    FINAL_BAKE_TIME_IN_MINUTES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    replicate_to: builtins.str
    growth_type: builtins.str
    description: builtins.str
    deployment_duration_in_minutes: builtins.float
    growth_factor: builtins.float
    final_bake_time_in_minutes: builtins.float
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentStrategyTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        replicate_to: builtins.str = ...,
        growth_type: builtins.str = ...,
        description: builtins.str = ...,
        deployment_duration_in_minutes: builtins.float = ...,
        growth_factor: builtins.float = ...,
        final_bake_time_in_minutes: builtins.float = ...,
        tags: collections.abc.Iterable[global___DeploymentStrategyTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_duration_in_minutes", b"deployment_duration_in_minutes", "description", b"description", "final_bake_time_in_minutes", b"final_bake_time_in_minutes", "growth_factor", b"growth_factor", "growth_type", b"growth_type", "name", b"name", "replicate_to", b"replicate_to", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DeploymentStrategy = DeploymentStrategy

@typing_extensions.final
class EnvironmentMonitors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_ARN_FIELD_NUMBER: builtins.int
    ALARM_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_arn: builtins.str
    alarm_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_arn: builtins.str = ...,
        alarm_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_arn", b"alarm_arn", "alarm_role_arn", b"alarm_role_arn", "resource_info", b"resource_info"]) -> None: ...

global___EnvironmentMonitors = EnvironmentMonitors

@typing_extensions.final
class EnvironmentTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___EnvironmentTags = EnvironmentTags

@typing_extensions.final
class Environment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MONITORS_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def monitors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentMonitors]: ...
    application_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentTags]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        monitors: collections.abc.Iterable[global___EnvironmentMonitors] | None = ...,
        application_id: builtins.str = ...,
        tags: collections.abc.Iterable[global___EnvironmentTags] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "description", b"description", "monitors", b"monitors", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Environment = Environment

@typing_extensions.final
class HostedConfigurationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROFILE_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    LATEST_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    configuration_profile_id: builtins.str
    description: builtins.str
    content_type: builtins.str
    latest_version_number: builtins.float
    content: builtins.str
    application_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configuration_profile_id: builtins.str = ...,
        description: builtins.str = ...,
        content_type: builtins.str = ...,
        latest_version_number: builtins.float = ...,
        content: builtins.str = ...,
        application_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "configuration_profile_id", b"configuration_profile_id", "content", b"content", "content_type", b"content_type", "description", b"description", "latest_version_number", b"latest_version_number", "resource_info", b"resource_info"]) -> None: ...

global___HostedConfigurationVersion = HostedConfigurationVersion



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_artifact.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_artifact.proto\x12\x18oak9.tython.gcp.artifact\x1a\x13shared/shared.proto\"c\n&ArtifactRegistryRepositoryXMavenConfig\x12!\n\x19\x61llow_snapshot_overwrites\x18\x01 \x01(\x08\x12\x16\n\x0eversion_policy\x18\x02 \x01(\t\"U\n#ArtifactRegistryRepositoryXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb8\x04\n\x1a\x41rtifactRegistryRepository\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x05 \x01(\t\x12P\n\x06labels\x18\x06 \x03(\x0b\x32@.oak9.tython.gcp.artifact.ArtifactRegistryRepository.LabelsEntry\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x15\n\rrepository_id\x18\n \x01(\t\x12\x13\n\x0bupdate_time\x18\x0b \x01(\t\x12V\n\x0cmaven_config\x18\x0c \x01(\x0b\x32@.oak9.tython.gcp.artifact.ArtifactRegistryRepositoryXMavenConfig\x12O\n\x08timeouts\x18\r \x01(\x0b\x32=.oak9.tython.gcp.artifact.ArtifactRegistryRepositoryXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n.ArtifactRegistryRepositoryIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xac\x02\n$ArtifactRegistryRepositoryIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x12\n\nrepository\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12[\n\tcondition\x18\x08 \x01(\x0b\x32H.oak9.tython.gcp.artifact.ArtifactRegistryRepositoryIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"g\n-ArtifactRegistryRepositoryIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa9\x02\n#ArtifactRegistryRepositoryIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x12\n\nrepository\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12Z\n\tcondition\x18\x08 \x01(\x0b\x32G.oak9.tython.gcp.artifact.ArtifactRegistryRepositoryIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n#ArtifactRegistryRepositoryIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x12\n\nrepository\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_artifact_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ARTIFACTREGISTRYREPOSITORY_LABELSENTRY._options = None
  _ARTIFACTREGISTRYREPOSITORY_LABELSENTRY._serialized_options = b'8\001'
  _ARTIFACTREGISTRYREPOSITORYXMAVENCONFIG._serialized_start=73
  _ARTIFACTREGISTRYREPOSITORYXMAVENCONFIG._serialized_end=172
  _ARTIFACTREGISTRYREPOSITORYXTIMEOUTS._serialized_start=174
  _ARTIFACTREGISTRYREPOSITORYXTIMEOUTS._serialized_end=259
  _ARTIFACTREGISTRYREPOSITORY._serialized_start=262
  _ARTIFACTREGISTRYREPOSITORY._serialized_end=830
  _ARTIFACTREGISTRYREPOSITORY_LABELSENTRY._serialized_start=785
  _ARTIFACTREGISTRYREPOSITORY_LABELSENTRY._serialized_end=830
  _ARTIFACTREGISTRYREPOSITORYIAMBINDINGXCONDITION._serialized_start=832
  _ARTIFACTREGISTRYREPOSITORYIAMBINDINGXCONDITION._serialized_end=936
  _ARTIFACTREGISTRYREPOSITORYIAMBINDING._serialized_start=939
  _ARTIFACTREGISTRYREPOSITORYIAMBINDING._serialized_end=1239
  _ARTIFACTREGISTRYREPOSITORYIAMMEMBERXCONDITION._serialized_start=1241
  _ARTIFACTREGISTRYREPOSITORYIAMMEMBERXCONDITION._serialized_end=1344
  _ARTIFACTREGISTRYREPOSITORYIAMMEMBER._serialized_start=1347
  _ARTIFACTREGISTRYREPOSITORYIAMMEMBER._serialized_end=1644
  _ARTIFACTREGISTRYREPOSITORYIAMPOLICY._serialized_start=1647
  _ARTIFACTREGISTRYREPOSITORYIAMPOLICY._serialized_end=1843
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticsearch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_elasticsearch.proto\x12\x1doak9.tython.aws.elasticsearch\x1a\x13shared/shared.proto\"\xa3\x01\n\x17\x44omainMasterUserOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fmaster_user_arn\x18\x02 \x01(\t\x12\x18\n\x10master_user_name\x18\x03 \x01(\t\x12\x1c\n\x14master_user_password\x18\x04 \x01(\t\"\xeb\x01\n\"DomainAdvancedSecurityOptionsInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12&\n\x1einternal_user_database_enabled\x18\x03 \x01(\x08\x12S\n\x13master_user_options\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.elasticsearch.DomainMasterUserOptions\"\xa2\x01\n\x14\x44omainCognitoOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10identity_pool_id\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x05 \x01(\t\"\x8b\x01\n\x1b\x44omainDomainEndpointOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65nforce_http_s\x18\x02 \x01(\x08\x12\x1b\n\x13tls_security_policy\x18\x03 \x01(\t\"\x98\x01\n\x10\x44omainEBSOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65\x62s_enabled\x18\x02 \x01(\x08\x12\x0c\n\x04iops\x18\x03 \x01(\x05\x12\x13\n\x0bvolume_size\x18\x04 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x05 \x01(\t\"u\n\x19\x44omainZoneAwarenessConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x61vailability_zone_count\x18\x02 \x01(\x05\"\xe4\x02\n DomainElasticsearchClusterConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65\x64icated_master_count\x18\x02 \x01(\x05\x12 \n\x18\x64\x65\x64icated_master_enabled\x18\x03 \x01(\x08\x12\x1d\n\x15\x64\x65\x64icated_master_type\x18\x04 \x01(\t\x12\x16\n\x0einstance_count\x18\x05 \x01(\x05\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12W\n\x15zone_awareness_config\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.elasticsearch.DomainZoneAwarenessConfig\x12\x1e\n\x16zone_awareness_enabled\x18\x08 \x01(\x08\"}\n\x1d\x44omainEncryptionAtRestOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x12\n\nkms_key_id\x18\x03 \x01(\t\"m\n!DomainNodeToNodeEncryptionOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"w\n\x15\x44omainSnapshotOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x61utomated_snapshot_start_hour\x18\x02 \x01(\x05\"{\n\x10\x44omainVPCOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\"\xf0\n\n\x06\x44omain\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0f\x61\x63\x63\x65ss_policies\x18\x02 \x03(\x0b\x32\x39.oak9.tython.aws.elasticsearch.Domain.AccessPoliciesEntry\x12T\n\x10\x61\x64vanced_options\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.elasticsearch.Domain.AdvancedOptionsEntry\x12\x64\n\x19\x61\x64vanced_security_options\x18\x04 \x01(\x0b\x32\x41.oak9.tython.aws.elasticsearch.DomainAdvancedSecurityOptionsInput\x12L\n\x0f\x63ognito_options\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.elasticsearch.DomainCognitoOptions\x12[\n\x17\x64omain_endpoint_options\x18\x06 \x01(\x0b\x32:.oak9.tython.aws.elasticsearch.DomainDomainEndpointOptions\x12\x13\n\x0b\x64omain_name\x18\x07 \x01(\t\x12\x44\n\x0b\x65\x62s_options\x18\x08 \x01(\x0b\x32/.oak9.tython.aws.elasticsearch.DomainEBSOptions\x12\x65\n\x1c\x65lasticsearch_cluster_config\x18\t \x01(\x0b\x32?.oak9.tython.aws.elasticsearch.DomainElasticsearchClusterConfig\x12\x1d\n\x15\x65lasticsearch_version\x18\n \x01(\t\x12`\n\x1a\x65ncryption_at_rest_options\x18\x0b \x01(\x0b\x32<.oak9.tython.aws.elasticsearch.DomainEncryptionAtRestOptions\x12i\n\x1fnode_to_node_encryption_options\x18\x0c \x01(\x0b\x32@.oak9.tython.aws.elasticsearch.DomainNodeToNodeEncryptionOptions\x12N\n\x10snapshot_options\x18\r \x01(\x0b\x32\x34.oak9.tython.aws.elasticsearch.DomainSnapshotOptions\x12=\n\x04tags\x18\x0e \x03(\x0b\x32/.oak9.tython.aws.elasticsearch.Domain.TagsEntry\x12\x44\n\x0bvpc_options\x18\x0f \x01(\x0b\x32/.oak9.tython.aws.elasticsearch.DomainVPCOptions\x12S\n\x16log_publishing_options\x18\x10 \x01(\x0b\x32\x33.oak9.tython.aws.elasticsearch.LogPublishingOptions\x1a\x35\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14\x41\x64vancedOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\rElasticsearch\x12\x35\n\x06\x64omain\x18\x01 \x01(\x0b\x32%.oak9.tython.aws.elasticsearch.Domain\"_\n\x14LogPublishingOptions\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12$\n\x1c\x63loudwatchlogs_log_group_arn\x18\x02 \x01(\t\x12\x10\n\x08log_type\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticsearch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAIN_ACCESSPOLICIESENTRY._options = None
  _DOMAIN_ACCESSPOLICIESENTRY._serialized_options = b'8\001'
  _DOMAIN_ADVANCEDOPTIONSENTRY._options = None
  _DOMAIN_ADVANCEDOPTIONSENTRY._serialized_options = b'8\001'
  _DOMAIN_TAGSENTRY._options = None
  _DOMAIN_TAGSENTRY._serialized_options = b'8\001'
  _DOMAINMASTERUSEROPTIONS._serialized_start=84
  _DOMAINMASTERUSEROPTIONS._serialized_end=247
  _DOMAINADVANCEDSECURITYOPTIONSINPUT._serialized_start=250
  _DOMAINADVANCEDSECURITYOPTIONSINPUT._serialized_end=485
  _DOMAINCOGNITOOPTIONS._serialized_start=488
  _DOMAINCOGNITOOPTIONS._serialized_end=650
  _DOMAINDOMAINENDPOINTOPTIONS._serialized_start=653
  _DOMAINDOMAINENDPOINTOPTIONS._serialized_end=792
  _DOMAINEBSOPTIONS._serialized_start=795
  _DOMAINEBSOPTIONS._serialized_end=947
  _DOMAINZONEAWARENESSCONFIG._serialized_start=949
  _DOMAINZONEAWARENESSCONFIG._serialized_end=1066
  _DOMAINELASTICSEARCHCLUSTERCONFIG._serialized_start=1069
  _DOMAINELASTICSEARCHCLUSTERCONFIG._serialized_end=1425
  _DOMAINENCRYPTIONATRESTOPTIONS._serialized_start=1427
  _DOMAINENCRYPTIONATRESTOPTIONS._serialized_end=1552
  _DOMAINNODETONODEENCRYPTIONOPTIONS._serialized_start=1554
  _DOMAINNODETONODEENCRYPTIONOPTIONS._serialized_end=1663
  _DOMAINSNAPSHOTOPTIONS._serialized_start=1665
  _DOMAINSNAPSHOTOPTIONS._serialized_end=1784
  _DOMAINVPCOPTIONS._serialized_start=1786
  _DOMAINVPCOPTIONS._serialized_end=1909
  _DOMAIN._serialized_start=1912
  _DOMAIN._serialized_end=3304
  _DOMAIN_ACCESSPOLICIESENTRY._serialized_start=3150
  _DOMAIN_ACCESSPOLICIESENTRY._serialized_end=3203
  _DOMAIN_ADVANCEDOPTIONSENTRY._serialized_start=3205
  _DOMAIN_ADVANCEDOPTIONSENTRY._serialized_end=3259
  _DOMAIN_TAGSENTRY._serialized_start=3261
  _DOMAIN_TAGSENTRY._serialized_end=3304
  _ELASTICSEARCH._serialized_start=3306
  _ELASTICSEARCH._serialized_end=3376
  _LOGPUBLISHINGOPTIONS._serialized_start=3378
  _LOGPUBLISHINGOPTIONS._serialized_end=3473
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class OrgPolicyPolicyXSpecXRulesXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    location: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        location: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "location", b"location", "title", b"title"]) -> None: ...

global___OrgPolicyPolicyXSpecXRulesXCondition = OrgPolicyPolicyXSpecXRulesXCondition

@typing_extensions.final
class OrgPolicyPolicyXSpecXRulesXValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_VALUES_FIELD_NUMBER: builtins.int
    DENIED_VALUES_FIELD_NUMBER: builtins.int
    @property
    def allowed_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def denied_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_values: collections.abc.Iterable[builtins.str] | None = ...,
        denied_values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_values", b"allowed_values", "denied_values", b"denied_values"]) -> None: ...

global___OrgPolicyPolicyXSpecXRulesXValues = OrgPolicyPolicyXSpecXRulesXValues

@typing_extensions.final
class OrgPolicyPolicyXSpecXRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_ALL_FIELD_NUMBER: builtins.int
    DENY_ALL_FIELD_NUMBER: builtins.int
    ENFORCE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    allow_all: builtins.str
    deny_all: builtins.str
    enforce: builtins.str
    @property
    def condition(self) -> global___OrgPolicyPolicyXSpecXRulesXCondition: ...
    @property
    def values(self) -> global___OrgPolicyPolicyXSpecXRulesXValues: ...
    def __init__(
        self,
        *,
        allow_all: builtins.str = ...,
        deny_all: builtins.str = ...,
        enforce: builtins.str = ...,
        condition: global___OrgPolicyPolicyXSpecXRulesXCondition | None = ...,
        values: global___OrgPolicyPolicyXSpecXRulesXValues | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "values", b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_all", b"allow_all", "condition", b"condition", "deny_all", b"deny_all", "enforce", b"enforce", "values", b"values"]) -> None: ...

global___OrgPolicyPolicyXSpecXRules = OrgPolicyPolicyXSpecXRules

@typing_extensions.final
class OrgPolicyPolicyXSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    INHERIT_FROM_PARENT_FIELD_NUMBER: builtins.int
    RESET_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    etag: builtins.str
    inherit_from_parent: builtins.bool
    reset: builtins.bool
    update_time: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OrgPolicyPolicyXSpecXRules]: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        inherit_from_parent: builtins.bool = ...,
        reset: builtins.bool = ...,
        update_time: builtins.str = ...,
        rules: collections.abc.Iterable[global___OrgPolicyPolicyXSpecXRules] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "inherit_from_parent", b"inherit_from_parent", "reset", b"reset", "rules", b"rules", "update_time", b"update_time"]) -> None: ...

global___OrgPolicyPolicyXSpec = OrgPolicyPolicyXSpec

@typing_extensions.final
class OrgPolicyPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___OrgPolicyPolicyXTimeouts = OrgPolicyPolicyXTimeouts

@typing_extensions.final
class OrgPolicyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    @property
    def spec(self) -> global___OrgPolicyPolicyXSpec: ...
    @property
    def timeouts(self) -> global___OrgPolicyPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        spec: global___OrgPolicyPolicyXSpec | None = ...,
        timeouts: global___OrgPolicyPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "spec", b"spec", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "spec", b"spec", "timeouts", b"timeouts"]) -> None: ...

global___OrgPolicyPolicy = OrgPolicyPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeExternalVpnGatewayXInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    id: builtins.float
    ip_address: builtins.str
    def __init__(
        self,
        *,
        id: builtins.float = ...,
        ip_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "ip_address", b"ip_address"]) -> None: ...

global___ComputeExternalVpnGatewayXInterface = ComputeExternalVpnGatewayXInterface

@typing_extensions.final
class ComputeExternalVpnGatewayXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeExternalVpnGatewayXTimeouts = ComputeExternalVpnGatewayXTimeouts

@typing_extensions.final
class ComputeExternalVpnGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REDUNDANCY_TYPE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    INTERFACE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    redundancy_type: builtins.str
    self_link: builtins.str
    @property
    def interface(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeExternalVpnGatewayXInterface]: ...
    @property
    def timeouts(self) -> global___ComputeExternalVpnGatewayXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        redundancy_type: builtins.str = ...,
        self_link: builtins.str = ...,
        interface: collections.abc.Iterable[global___ComputeExternalVpnGatewayXInterface] | None = ...,
        timeouts: global___ComputeExternalVpnGatewayXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "interface", b"interface", "name", b"name", "project", b"project", "redundancy_type", b"redundancy_type", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeExternalVpnGateway = ComputeExternalVpnGateway



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApiCache(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TRANSIT_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    AT_REST_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    API_CACHING_BEHAVIOR_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    transit_encryption_enabled: builtins.bool
    at_rest_encryption_enabled: builtins.bool
    api_id: builtins.str
    api_caching_behavior: builtins.str
    ttl: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        transit_encryption_enabled: builtins.bool = ...,
        at_rest_encryption_enabled: builtins.bool = ...,
        api_id: builtins.str = ...,
        api_caching_behavior: builtins.str = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_caching_behavior", b"api_caching_behavior", "api_id", b"api_id", "at_rest_encryption_enabled", b"at_rest_encryption_enabled", "resource_info", b"resource_info", "transit_encryption_enabled", b"transit_encryption_enabled", "ttl", b"ttl", "type", b"type"]) -> None: ...

global___ApiCache = ApiCache

@typing_extensions.final
class AppSync(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_CACHE_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    DATA_SOURCE_FIELD_NUMBER: builtins.int
    FUNCTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    GRAPH_Q_L_API_FIELD_NUMBER: builtins.int
    GRAPH_Q_L_SCHEMA_FIELD_NUMBER: builtins.int
    RESOLVER_FIELD_NUMBER: builtins.int
    GRAPH_Q_L_API_ADDITIONAL_AUTHENTICATION_PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def api_cache(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiCache]: ...
    @property
    def api_key(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiKey]: ...
    @property
    def data_source(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataSource]: ...
    @property
    def function_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionConfiguration]: ...
    @property
    def graph_q_l_api(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GraphQLApi]: ...
    @property
    def graph_q_l_schema(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GraphQLSchema]: ...
    @property
    def resolver(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Resolver]: ...
    @property
    def graph_q_l_api_additional_authentication_provider(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GraphQLApiAdditionalAuthenticationProvider]: ...
    def __init__(
        self,
        *,
        api_cache: collections.abc.Iterable[global___ApiCache] | None = ...,
        api_key: collections.abc.Iterable[global___ApiKey] | None = ...,
        data_source: collections.abc.Iterable[global___DataSource] | None = ...,
        function_configuration: collections.abc.Iterable[global___FunctionConfiguration] | None = ...,
        graph_q_l_api: collections.abc.Iterable[global___GraphQLApi] | None = ...,
        graph_q_l_schema: collections.abc.Iterable[global___GraphQLSchema] | None = ...,
        resolver: collections.abc.Iterable[global___Resolver] | None = ...,
        graph_q_l_api_additional_authentication_provider: collections.abc.Iterable[global___GraphQLApiAdditionalAuthenticationProvider] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_cache", b"api_cache", "api_key", b"api_key", "data_source", b"data_source", "function_configuration", b"function_configuration", "graph_q_l_api", b"graph_q_l_api", "graph_q_l_api_additional_authentication_provider", b"graph_q_l_api_additional_authentication_provider", "graph_q_l_schema", b"graph_q_l_schema", "resolver", b"resolver"]) -> None: ...

global___AppSync = AppSync

@typing_extensions.final
class ApiKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRES_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    expires: builtins.float
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        expires: builtins.float = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "description", b"description", "expires", b"expires", "resource_info", b"resource_info"]) -> None: ...

global___ApiKey = ApiKey

@typing_extensions.final
class DataSourceAwsIamConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SIGNING_REGION_FIELD_NUMBER: builtins.int
    SIGNING_SERVICE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    signing_region: builtins.str
    signing_service_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        signing_region: builtins.str = ...,
        signing_service_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "signing_region", b"signing_region", "signing_service_name", b"signing_service_name"]) -> None: ...

global___DataSourceAwsIamConfig = DataSourceAwsIamConfig

@typing_extensions.final
class DataSourceAuthorizationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_IAM_CONFIG_FIELD_NUMBER: builtins.int
    AUTHORIZATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def aws_iam_config(self) -> global___DataSourceAwsIamConfig: ...
    authorization_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_iam_config: global___DataSourceAwsIamConfig | None = ...,
        authorization_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_iam_config", b"aws_iam_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization_type", b"authorization_type", "aws_iam_config", b"aws_iam_config", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceAuthorizationConfig = DataSourceAuthorizationConfig

@typing_extensions.final
class DataSourceHttpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    AUTHORIZATION_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    endpoint: builtins.str
    @property
    def authorization_config(self) -> global___DataSourceAuthorizationConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint: builtins.str = ...,
        authorization_config: global___DataSourceAuthorizationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization_config", b"authorization_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization_config", b"authorization_config", "endpoint", b"endpoint", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceHttpConfig = DataSourceHttpConfig

@typing_extensions.final
class DataSourceRdsHttpEndpointConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    DB_CLUSTER_IDENTIFIER_FIELD_NUMBER: builtins.int
    AWS_SECRET_STORE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    aws_region: builtins.str
    schema: builtins.str
    database_name: builtins.str
    db_cluster_identifier: builtins.str
    aws_secret_store_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_region: builtins.str = ...,
        schema: builtins.str = ...,
        database_name: builtins.str = ...,
        db_cluster_identifier: builtins.str = ...,
        aws_secret_store_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_region", b"aws_region", "aws_secret_store_arn", b"aws_secret_store_arn", "database_name", b"database_name", "db_cluster_identifier", b"db_cluster_identifier", "resource_info", b"resource_info", "schema", b"schema"]) -> None: ...

global___DataSourceRdsHttpEndpointConfig = DataSourceRdsHttpEndpointConfig

@typing_extensions.final
class DataSourceRelationalDatabaseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RDS_HTTP_ENDPOINT_CONFIG_FIELD_NUMBER: builtins.int
    RELATIONAL_DATABASE_SOURCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def rds_http_endpoint_config(self) -> global___DataSourceRdsHttpEndpointConfig: ...
    relational_database_source_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rds_http_endpoint_config: global___DataSourceRdsHttpEndpointConfig | None = ...,
        relational_database_source_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rds_http_endpoint_config", b"rds_http_endpoint_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["rds_http_endpoint_config", b"rds_http_endpoint_config", "relational_database_source_type", b"relational_database_source_type", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceRelationalDatabaseConfig = DataSourceRelationalDatabaseConfig

@typing_extensions.final
class DataSourceLambdaConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAMBDA_FUNCTION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    lambda_function_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        lambda_function_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lambda_function_arn", b"lambda_function_arn", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceLambdaConfig = DataSourceLambdaConfig

@typing_extensions.final
class DataSourceDeltaSyncConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BASE_TABLE_TTL_FIELD_NUMBER: builtins.int
    DELTA_SYNC_TABLE_TTL_FIELD_NUMBER: builtins.int
    DELTA_SYNC_TABLE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    base_table_ttl: builtins.str
    delta_sync_table_ttl: builtins.str
    delta_sync_table_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        base_table_ttl: builtins.str = ...,
        delta_sync_table_ttl: builtins.str = ...,
        delta_sync_table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_table_ttl", b"base_table_ttl", "delta_sync_table_name", b"delta_sync_table_name", "delta_sync_table_ttl", b"delta_sync_table_ttl", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceDeltaSyncConfig = DataSourceDeltaSyncConfig

@typing_extensions.final
class DataSourceDynamoDBConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    VERSIONED_FIELD_NUMBER: builtins.int
    DELTA_SYNC_CONFIG_FIELD_NUMBER: builtins.int
    USE_CALLER_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    table_name: builtins.str
    aws_region: builtins.str
    versioned: builtins.bool
    @property
    def delta_sync_config(self) -> global___DataSourceDeltaSyncConfig: ...
    use_caller_credentials: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        table_name: builtins.str = ...,
        aws_region: builtins.str = ...,
        versioned: builtins.bool = ...,
        delta_sync_config: global___DataSourceDeltaSyncConfig | None = ...,
        use_caller_credentials: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delta_sync_config", b"delta_sync_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_region", b"aws_region", "delta_sync_config", b"delta_sync_config", "resource_info", b"resource_info", "table_name", b"table_name", "use_caller_credentials", b"use_caller_credentials", "versioned", b"versioned"]) -> None: ...

global___DataSourceDynamoDBConfig = DataSourceDynamoDBConfig

@typing_extensions.final
class DataSourceElasticsearchConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    aws_region: builtins.str
    endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_region: builtins.str = ...,
        endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_region", b"aws_region", "endpoint", b"endpoint", "resource_info", b"resource_info"]) -> None: ...

global___DataSourceElasticsearchConfig = DataSourceElasticsearchConfig

@typing_extensions.final
class DataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    HTTP_CONFIG_FIELD_NUMBER: builtins.int
    RELATIONAL_DATABASE_CONFIG_FIELD_NUMBER: builtins.int
    LAMBDA_CONFIG_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DYNAMO_DB_CONFIG_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    description: builtins.str
    service_role_arn: builtins.str
    @property
    def http_config(self) -> global___DataSourceHttpConfig: ...
    @property
    def relational_database_config(self) -> global___DataSourceRelationalDatabaseConfig: ...
    @property
    def lambda_config(self) -> global___DataSourceLambdaConfig: ...
    api_id: builtins.str
    name: builtins.str
    @property
    def dynamo_db_config(self) -> global___DataSourceDynamoDBConfig: ...
    @property
    def elasticsearch_config(self) -> global___DataSourceElasticsearchConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        description: builtins.str = ...,
        service_role_arn: builtins.str = ...,
        http_config: global___DataSourceHttpConfig | None = ...,
        relational_database_config: global___DataSourceRelationalDatabaseConfig | None = ...,
        lambda_config: global___DataSourceLambdaConfig | None = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
        dynamo_db_config: global___DataSourceDynamoDBConfig | None = ...,
        elasticsearch_config: global___DataSourceElasticsearchConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamo_db_config", b"dynamo_db_config", "elasticsearch_config", b"elasticsearch_config", "http_config", b"http_config", "lambda_config", b"lambda_config", "relational_database_config", b"relational_database_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "description", b"description", "dynamo_db_config", b"dynamo_db_config", "elasticsearch_config", b"elasticsearch_config", "http_config", b"http_config", "lambda_config", b"lambda_config", "name", b"name", "relational_database_config", b"relational_database_config", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "type", b"type"]) -> None: ...

global___DataSource = DataSource

@typing_extensions.final
class FunctionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    FUNCTION_VERSION_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    response_mapping_template_s3_location: builtins.str
    description: builtins.str
    data_source_name: builtins.str
    request_mapping_template: builtins.str
    response_mapping_template: builtins.str
    function_version: builtins.str
    request_mapping_template_s3_location: builtins.str
    api_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_mapping_template_s3_location: builtins.str = ...,
        description: builtins.str = ...,
        data_source_name: builtins.str = ...,
        request_mapping_template: builtins.str = ...,
        response_mapping_template: builtins.str = ...,
        function_version: builtins.str = ...,
        request_mapping_template_s3_location: builtins.str = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "data_source_name", b"data_source_name", "description", b"description", "function_version", b"function_version", "name", b"name", "request_mapping_template", b"request_mapping_template", "request_mapping_template_s3_location", b"request_mapping_template_s3_location", "resource_info", b"resource_info", "response_mapping_template", b"response_mapping_template", "response_mapping_template_s3_location", b"response_mapping_template_s3_location"]) -> None: ...

global___FunctionConfiguration = FunctionConfiguration

@typing_extensions.final
class GraphQLApiOpenIDConnectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    AUTH_TTL_FIELD_NUMBER: builtins.int
    IAT_TTL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    issuer: builtins.str
    client_id: builtins.str
    auth_ttl: builtins.float
    iat_ttl: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        issuer: builtins.str = ...,
        client_id: builtins.str = ...,
        auth_ttl: builtins.float = ...,
        iat_ttl: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_ttl", b"auth_ttl", "client_id", b"client_id", "iat_ttl", b"iat_ttl", "issuer", b"issuer", "resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiOpenIDConnectConfig = GraphQLApiOpenIDConnectConfig

@typing_extensions.final
class GraphQLApiUserPoolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APP_ID_CLIENT_REGEX_FIELD_NUMBER: builtins.int
    USER_POOL_ID_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    app_id_client_regex: builtins.str
    user_pool_id: builtins.str
    aws_region: builtins.str
    default_action: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        app_id_client_regex: builtins.str = ...,
        user_pool_id: builtins.str = ...,
        aws_region: builtins.str = ...,
        default_action: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id_client_regex", b"app_id_client_regex", "aws_region", b"aws_region", "default_action", b"default_action", "resource_info", b"resource_info", "user_pool_id", b"user_pool_id"]) -> None: ...

global___GraphQLApiUserPoolConfig = GraphQLApiUserPoolConfig

@typing_extensions.final
class GraphQLApiTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiTags = GraphQLApiTags

@typing_extensions.final
class GraphQLApiLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGS_ROLE_ARN_FIELD_NUMBER: builtins.int
    EXCLUDE_VERBOSE_CONTENT_FIELD_NUMBER: builtins.int
    FIELD_LOG_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cloud_watch_logs_role_arn: builtins.str
    exclude_verbose_content: builtins.bool
    field_log_level: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logs_role_arn: builtins.str = ...,
        exclude_verbose_content: builtins.bool = ...,
        field_log_level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logs_role_arn", b"cloud_watch_logs_role_arn", "exclude_verbose_content", b"exclude_verbose_content", "field_log_level", b"field_log_level", "resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiLogConfig = GraphQLApiLogConfig

@typing_extensions.final
class GraphQLApiAdditionalAuthenticationProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___GraphQLApiAdditionalAuthenticationProviders = GraphQLApiAdditionalAuthenticationProviders

@typing_extensions.final
class GraphQLApi(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OPEN_ID_CONNECT_CONFIG_FIELD_NUMBER: builtins.int
    XRAY_ENABLED_FIELD_NUMBER: builtins.int
    USER_POOL_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    ADDITIONAL_AUTHENTICATION_PROVIDERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def open_id_connect_config(self) -> global___GraphQLApiOpenIDConnectConfig: ...
    xray_enabled: builtins.bool
    @property
    def user_pool_config(self) -> global___GraphQLApiUserPoolConfig: ...
    @property
    def tags(self) -> global___GraphQLApiTags: ...
    name: builtins.str
    authentication_type: builtins.str
    @property
    def log_config(self) -> global___GraphQLApiLogConfig: ...
    @property
    def additional_authentication_providers(self) -> global___GraphQLApiAdditionalAuthenticationProviders: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        open_id_connect_config: global___GraphQLApiOpenIDConnectConfig | None = ...,
        xray_enabled: builtins.bool = ...,
        user_pool_config: global___GraphQLApiUserPoolConfig | None = ...,
        tags: global___GraphQLApiTags | None = ...,
        name: builtins.str = ...,
        authentication_type: builtins.str = ...,
        log_config: global___GraphQLApiLogConfig | None = ...,
        additional_authentication_providers: global___GraphQLApiAdditionalAuthenticationProviders | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional_authentication_providers", b"additional_authentication_providers", "log_config", b"log_config", "open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "tags", b"tags", "user_pool_config", b"user_pool_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_authentication_providers", b"additional_authentication_providers", "authentication_type", b"authentication_type", "log_config", b"log_config", "name", b"name", "open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "tags", b"tags", "user_pool_config", b"user_pool_config", "xray_enabled", b"xray_enabled"]) -> None: ...

global___GraphQLApi = GraphQLApi

@typing_extensions.final
class GraphQLSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEFINITION_FIELD_NUMBER: builtins.int
    DEFINITION_S3_LOCATION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    definition: builtins.str
    definition_s3_location: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        definition: builtins.str = ...,
        definition_s3_location: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "definition", b"definition", "definition_s3_location", b"definition_s3_location", "resource_info", b"resource_info"]) -> None: ...

global___GraphQLSchema = GraphQLSchema

@typing_extensions.final
class ResolverPipelineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FUNCTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        functions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["functions", b"functions", "resource_info", b"resource_info"]) -> None: ...

global___ResolverPipelineConfig = ResolverPipelineConfig

@typing_extensions.final
class ResolverCachingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHING_KEYS_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def caching_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ttl: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        caching_keys: collections.abc.Iterable[builtins.str] | None = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caching_keys", b"caching_keys", "resource_info", b"resource_info", "ttl", b"ttl"]) -> None: ...

global___ResolverCachingConfig = ResolverCachingConfig

@typing_extensions.final
class ResolverLambdaConflictHandlerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAMBDA_CONFLICT_HANDLER_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    lambda_conflict_handler_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        lambda_conflict_handler_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lambda_conflict_handler_arn", b"lambda_conflict_handler_arn", "resource_info", b"resource_info"]) -> None: ...

global___ResolverLambdaConflictHandlerConfig = ResolverLambdaConflictHandlerConfig

@typing_extensions.final
class ResolverSyncConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFLICT_HANDLER_FIELD_NUMBER: builtins.int
    CONFLICT_DETECTION_FIELD_NUMBER: builtins.int
    LAMBDA_CONFLICT_HANDLER_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    conflict_handler: builtins.str
    conflict_detection: builtins.str
    @property
    def lambda_conflict_handler_config(self) -> global___ResolverLambdaConflictHandlerConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        conflict_handler: builtins.str = ...,
        conflict_detection: builtins.str = ...,
        lambda_conflict_handler_config: global___ResolverLambdaConflictHandlerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lambda_conflict_handler_config", b"lambda_conflict_handler_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflict_detection", b"conflict_detection", "conflict_handler", b"conflict_handler", "lambda_conflict_handler_config", b"lambda_conflict_handler_config", "resource_info", b"resource_info"]) -> None: ...

global___ResolverSyncConfig = ResolverSyncConfig

@typing_extensions.final
class Resolver(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    PIPELINE_CONFIG_FIELD_NUMBER: builtins.int
    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    RESPONSE_MAPPING_TEMPLATE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    CACHING_CONFIG_FIELD_NUMBER: builtins.int
    SYNC_CONFIG_FIELD_NUMBER: builtins.int
    REQUEST_MAPPING_TEMPLATE_S3_LOCATION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    FIELD_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    response_mapping_template_s3_location: builtins.str
    type_name: builtins.str
    @property
    def pipeline_config(self) -> global___ResolverPipelineConfig: ...
    data_source_name: builtins.str
    request_mapping_template: builtins.str
    response_mapping_template: builtins.str
    kind: builtins.str
    @property
    def caching_config(self) -> global___ResolverCachingConfig: ...
    @property
    def sync_config(self) -> global___ResolverSyncConfig: ...
    request_mapping_template_s3_location: builtins.str
    api_id: builtins.str
    field_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_mapping_template_s3_location: builtins.str = ...,
        type_name: builtins.str = ...,
        pipeline_config: global___ResolverPipelineConfig | None = ...,
        data_source_name: builtins.str = ...,
        request_mapping_template: builtins.str = ...,
        response_mapping_template: builtins.str = ...,
        kind: builtins.str = ...,
        caching_config: global___ResolverCachingConfig | None = ...,
        sync_config: global___ResolverSyncConfig | None = ...,
        request_mapping_template_s3_location: builtins.str = ...,
        api_id: builtins.str = ...,
        field_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["caching_config", b"caching_config", "pipeline_config", b"pipeline_config", "resource_info", b"resource_info", "sync_config", b"sync_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "caching_config", b"caching_config", "data_source_name", b"data_source_name", "field_name", b"field_name", "kind", b"kind", "pipeline_config", b"pipeline_config", "request_mapping_template", b"request_mapping_template", "request_mapping_template_s3_location", b"request_mapping_template_s3_location", "resource_info", b"resource_info", "response_mapping_template", b"response_mapping_template", "response_mapping_template_s3_location", b"response_mapping_template_s3_location", "sync_config", b"sync_config", "type_name", b"type_name"]) -> None: ...

global___Resolver = Resolver

@typing_extensions.final
class GraphQLApiCognitoUserPoolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APP_ID_CLIENT_REGEX_FIELD_NUMBER: builtins.int
    USER_POOL_ID_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    app_id_client_regex: builtins.str
    user_pool_id: builtins.str
    aws_region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        app_id_client_regex: builtins.str = ...,
        user_pool_id: builtins.str = ...,
        aws_region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id_client_regex", b"app_id_client_regex", "aws_region", b"aws_region", "resource_info", b"resource_info", "user_pool_id", b"user_pool_id"]) -> None: ...

global___GraphQLApiCognitoUserPoolConfig = GraphQLApiCognitoUserPoolConfig

@typing_extensions.final
class GraphQLApiAdditionalAuthenticationProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OPEN_ID_CONNECT_CONFIG_FIELD_NUMBER: builtins.int
    USER_POOL_CONFIG_FIELD_NUMBER: builtins.int
    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def open_id_connect_config(self) -> global___GraphQLApiOpenIDConnectConfig: ...
    @property
    def user_pool_config(self) -> global___GraphQLApiCognitoUserPoolConfig: ...
    authentication_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        open_id_connect_config: global___GraphQLApiOpenIDConnectConfig | None = ...,
        user_pool_config: global___GraphQLApiCognitoUserPoolConfig | None = ...,
        authentication_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "user_pool_config", b"user_pool_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "open_id_connect_config", b"open_id_connect_config", "resource_info", b"resource_info", "user_pool_config", b"user_pool_config"]) -> None: ...

global___GraphQLApiAdditionalAuthenticationProvider = GraphQLApiAdditionalAuthenticationProvider



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_cloudbuild.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_cloudbuild.proto\x12\x1aoak9.tython.gcp.cloudbuild\x1a\x13shared/shared.proto\"=\n CloudbuildTriggerXApprovalConfig\x12\x19\n\x11\x61pproval_required\x18\x01 \x01(\x08\"\xde\x01\n)CloudbuildTriggerXBuildXArtifactsXObjects\x12\x10\n\x08location\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\x12\x61\n\x06timing\x18\x03 \x03(\x0b\x32Q.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXArtifactsXObjects.TimingEntry\x1a-\n\x0bTimingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n!CloudbuildTriggerXBuildXArtifacts\x12\x0e\n\x06images\x18\x01 \x03(\t\x12V\n\x07objects\x18\x02 \x01(\x0b\x32\x45.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXArtifactsXObjects\"[\n6CloudbuildTriggerXBuildXAvailableSecretsXSecretManager\x12\x0b\n\x03\x65nv\x18\x01 \x01(\t\x12\x14\n\x0cversion_name\x18\x02 \x01(\t\"\x96\x01\n(CloudbuildTriggerXBuildXAvailableSecrets\x12j\n\x0esecret_manager\x18\x01 \x03(\x0b\x32R.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXAvailableSecretsXSecretManager\"E\n\'CloudbuildTriggerXBuildXOptionsXVolumes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x85\x03\n\x1f\x43loudbuildTriggerXBuildXOptions\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x1d\n\x15\x64ynamic_substitutions\x18\x02 \x01(\x08\x12\x0b\n\x03\x65nv\x18\x03 \x03(\t\x12\x1c\n\x14log_streaming_option\x18\x04 \x01(\t\x12\x0f\n\x07logging\x18\x05 \x01(\t\x12\x14\n\x0cmachine_type\x18\x06 \x01(\t\x12\x1f\n\x17requested_verify_option\x18\x07 \x01(\t\x12\x12\n\nsecret_env\x18\x08 \x03(\t\x12\x1e\n\x16source_provenance_hash\x18\t \x03(\t\x12\x1b\n\x13substitution_option\x18\n \x01(\t\x12\x13\n\x0bworker_pool\x18\x0b \x01(\t\x12T\n\x07volumes\x18\x0c \x03(\x0b\x32\x43.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXOptionsXVolumes\"\xc7\x01\n\x1e\x43loudbuildTriggerXBuildXSecret\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\x12]\n\nsecret_env\x18\x02 \x03(\x0b\x32I.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSecret.SecretEnvEntry\x1a\x30\n\x0eSecretEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\x02\n)CloudbuildTriggerXBuildXSourceXRepoSource\x12\x13\n\x0b\x62ranch_name\x18\x01 \x01(\t\x12\x12\n\ncommit_sha\x18\x02 \x01(\t\x12\x0b\n\x03\x64ir\x18\x03 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x04 \x01(\x08\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\trepo_name\x18\x06 \x01(\t\x12o\n\rsubstitutions\x18\x07 \x03(\x0b\x32X.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSourceXRepoSource.SubstitutionsEntry\x12\x10\n\x08tag_name\x18\x08 \x01(\t\x1a\x34\n\x12SubstitutionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n,CloudbuildTriggerXBuildXSourceXStorageSource\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\xde\x01\n\x1e\x43loudbuildTriggerXBuildXSource\x12Z\n\x0brepo_source\x18\x01 \x01(\x0b\x32\x45.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSourceXRepoSource\x12`\n\x0estorage_source\x18\x02 \x01(\x0b\x32H.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSourceXStorageSource\"B\n$CloudbuildTriggerXBuildXStepXVolumes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x8e\x02\n\x1c\x43loudbuildTriggerXBuildXStep\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0b\n\x03\x64ir\x18\x02 \x01(\t\x12\x12\n\nentrypoint\x18\x03 \x01(\t\x12\x0b\n\x03\x65nv\x18\x04 \x03(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x12\n\nsecret_env\x18\x07 \x03(\t\x12\x0f\n\x07timeout\x18\x08 \x01(\t\x12\x0e\n\x06timing\x18\t \x01(\t\x12\x10\n\x08wait_for\x18\n \x03(\t\x12Q\n\x07volumes\x18\x0b \x03(\x0b\x32@.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXStepXVolumes\"\xe6\x05\n\x17\x43loudbuildTriggerXBuild\x12\x0e\n\x06images\x18\x01 \x03(\t\x12\x13\n\x0blogs_bucket\x18\x02 \x01(\t\x12\x11\n\tqueue_ttl\x18\x03 \x01(\t\x12]\n\rsubstitutions\x18\x04 \x03(\x0b\x32\x46.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuild.SubstitutionsEntry\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\x0f\n\x07timeout\x18\x06 \x01(\t\x12P\n\tartifacts\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXArtifacts\x12_\n\x11\x61vailable_secrets\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXAvailableSecrets\x12L\n\x07options\x18\t \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXOptions\x12J\n\x06secret\x18\n \x03(\x0b\x32:.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSecret\x12J\n\x06source\x18\x0b \x01(\x0b\x32:.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXSource\x12\x46\n\x04step\x18\x0c \x03(\x0b\x32\x38.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuildXStep\x1a\x34\n\x12SubstitutionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x1f\x43loudbuildTriggerXGitFileSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\trepo_type\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"e\n$CloudbuildTriggerXGithubXPullRequest\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12\x17\n\x0f\x63omment_control\x18\x02 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x03 \x01(\x08\"R\n\x1d\x43loudbuildTriggerXGithubXPush\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x02 \x01(\x08\x12\x0b\n\x03tag\x18\x03 \x01(\t\"\xd8\x01\n\x18\x43loudbuildTriggerXGithub\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12V\n\x0cpull_request\x18\x03 \x01(\x0b\x32@.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGithubXPullRequest\x12G\n\x04push\x18\x04 \x01(\x0b\x32\x39.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGithubXPush\"s\n\x1e\x43loudbuildTriggerXPubsubConfig\x12\x1d\n\x15service_account_email\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x14\n\x0csubscription\x18\x03 \x01(\t\x12\r\n\x05topic\x18\x04 \x01(\t\"N\n\x1f\x43loudbuildTriggerXSourceToBuild\x12\x0b\n\x03ref\x18\x01 \x01(\t\x12\x11\n\trepo_type\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"L\n\x1a\x43loudbuildTriggerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa8\x01\n!CloudbuildTriggerXTriggerTemplate\x12\x13\n\x0b\x62ranch_name\x18\x01 \x01(\t\x12\x12\n\ncommit_sha\x18\x02 \x01(\t\x12\x0b\n\x03\x64ir\x18\x03 \x01(\t\x12\x14\n\x0cinvert_regex\x18\x04 \x01(\x08\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\trepo_name\x18\x06 \x01(\t\x12\x10\n\x08tag_name\x18\x07 \x01(\t\"@\n\x1f\x43loudbuildTriggerXWebhookConfig\x12\x0e\n\x06secret\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"\xc2\t\n\x11\x43loudbuildTrigger\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x15\n\rignored_files\x18\x07 \x03(\t\x12\x1a\n\x12include_build_logs\x18\x08 \x01(\t\x12\x16\n\x0eincluded_files\x18\t \x03(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x17\n\x0fservice_account\x18\x0c \x01(\t\x12W\n\rsubstitutions\x18\r \x03(\x0b\x32@.oak9.tython.gcp.cloudbuild.CloudbuildTrigger.SubstitutionsEntry\x12\x0c\n\x04tags\x18\x0e \x03(\t\x12\x12\n\ntrigger_id\x18\x0f \x01(\t\x12U\n\x0f\x61pproval_config\x18\x10 \x01(\x0b\x32<.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXApprovalConfig\x12\x42\n\x05\x62uild\x18\x11 \x01(\x0b\x32\x33.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXBuild\x12T\n\x0fgit_file_source\x18\x12 \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGitFileSource\x12\x44\n\x06github\x18\x13 \x01(\x0b\x32\x34.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXGithub\x12Q\n\rpubsub_config\x18\x14 \x01(\x0b\x32:.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXPubsubConfig\x12T\n\x0fsource_to_build\x18\x15 \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXSourceToBuild\x12H\n\x08timeouts\x18\x16 \x01(\x0b\x32\x36.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXTimeouts\x12W\n\x10trigger_template\x18\x17 \x01(\x0b\x32=.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXTriggerTemplate\x12S\n\x0ewebhook_config\x18\x18 \x01(\x0b\x32;.oak9.tython.gcp.cloudbuild.CloudbuildTriggerXWebhookConfig\x12\x37\n\rresource_info\x18\x19 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x34\n\x12SubstitutionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\"CloudbuildWorkerPoolXNetworkConfig\x12\x16\n\x0epeered_network\x18\x01 \x01(\t\"O\n\x1d\x43loudbuildWorkerPoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"g\n!CloudbuildWorkerPoolXWorkerConfig\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x14\n\x0cmachine_type\x18\x02 \x01(\t\x12\x16\n\x0eno_external_ip\x18\x03 \x01(\x08\"\x84\x05\n\x14\x43loudbuildWorkerPool\x12V\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x41.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPool.AnnotationsEntry\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65lete_time\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12\x0b\n\x03uid\x18\n \x01(\t\x12\x13\n\x0bupdate_time\x18\x0b \x01(\t\x12V\n\x0enetwork_config\x18\x0c \x01(\x0b\x32>.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPoolXNetworkConfig\x12K\n\x08timeouts\x18\r \x01(\x0b\x32\x39.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPoolXTimeouts\x12T\n\rworker_config\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.cloudbuild.CloudbuildWorkerPoolXWorkerConfig\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_cloudbuild_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._options = None
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._options = None
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._options = None
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLOUDBUILDTRIGGERXAPPROVALCONFIG._serialized_start=77
  _CLOUDBUILDTRIGGERXAPPROVALCONFIG._serialized_end=138
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS._serialized_start=141
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS._serialized_end=363
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._serialized_start=318
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTSXOBJECTS_TIMINGENTRY._serialized_end=363
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTS._serialized_start=366
  _CLOUDBUILDTRIGGERXBUILDXARTIFACTS._serialized_end=505
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETSXSECRETMANAGER._serialized_start=507
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETSXSECRETMANAGER._serialized_end=598
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETS._serialized_start=601
  _CLOUDBUILDTRIGGERXBUILDXAVAILABLESECRETS._serialized_end=751
  _CLOUDBUILDTRIGGERXBUILDXOPTIONSXVOLUMES._serialized_start=753
  _CLOUDBUILDTRIGGERXBUILDXOPTIONSXVOLUMES._serialized_end=822
  _CLOUDBUILDTRIGGERXBUILDXOPTIONS._serialized_start=825
  _CLOUDBUILDTRIGGERXBUILDXOPTIONS._serialized_end=1214
  _CLOUDBUILDTRIGGERXBUILDXSECRET._serialized_start=1217
  _CLOUDBUILDTRIGGERXBUILDXSECRET._serialized_end=1416
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._serialized_start=1368
  _CLOUDBUILDTRIGGERXBUILDXSECRET_SECRETENVENTRY._serialized_end=1416
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE._serialized_start=1419
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE._serialized_end=1762
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._serialized_start=1710
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXREPOSOURCE_SUBSTITUTIONSENTRY._serialized_end=1762
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXSTORAGESOURCE._serialized_start=1764
  _CLOUDBUILDTRIGGERXBUILDXSOURCEXSTORAGESOURCE._serialized_end=1862
  _CLOUDBUILDTRIGGERXBUILDXSOURCE._serialized_start=1865
  _CLOUDBUILDTRIGGERXBUILDXSOURCE._serialized_end=2087
  _CLOUDBUILDTRIGGERXBUILDXSTEPXVOLUMES._serialized_start=2089
  _CLOUDBUILDTRIGGERXBUILDXSTEPXVOLUMES._serialized_end=2155
  _CLOUDBUILDTRIGGERXBUILDXSTEP._serialized_start=2158
  _CLOUDBUILDTRIGGERXBUILDXSTEP._serialized_end=2428
  _CLOUDBUILDTRIGGERXBUILD._serialized_start=2431
  _CLOUDBUILDTRIGGERXBUILD._serialized_end=3173
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._serialized_start=1710
  _CLOUDBUILDTRIGGERXBUILD_SUBSTITUTIONSENTRY._serialized_end=1762
  _CLOUDBUILDTRIGGERXGITFILESOURCE._serialized_start=3175
  _CLOUDBUILDTRIGGERXGITFILESOURCE._serialized_end=3272
  _CLOUDBUILDTRIGGERXGITHUBXPULLREQUEST._serialized_start=3274
  _CLOUDBUILDTRIGGERXGITHUBXPULLREQUEST._serialized_end=3375
  _CLOUDBUILDTRIGGERXGITHUBXPUSH._serialized_start=3377
  _CLOUDBUILDTRIGGERXGITHUBXPUSH._serialized_end=3459
  _CLOUDBUILDTRIGGERXGITHUB._serialized_start=3462
  _CLOUDBUILDTRIGGERXGITHUB._serialized_end=3678
  _CLOUDBUILDTRIGGERXPUBSUBCONFIG._serialized_start=3680
  _CLOUDBUILDTRIGGERXPUBSUBCONFIG._serialized_end=3795
  _CLOUDBUILDTRIGGERXSOURCETOBUILD._serialized_start=3797
  _CLOUDBUILDTRIGGERXSOURCETOBUILD._serialized_end=3875
  _CLOUDBUILDTRIGGERXTIMEOUTS._serialized_start=3877
  _CLOUDBUILDTRIGGERXTIMEOUTS._serialized_end=3953
  _CLOUDBUILDTRIGGERXTRIGGERTEMPLATE._serialized_start=3956
  _CLOUDBUILDTRIGGERXTRIGGERTEMPLATE._serialized_end=4124
  _CLOUDBUILDTRIGGERXWEBHOOKCONFIG._serialized_start=4126
  _CLOUDBUILDTRIGGERXWEBHOOKCONFIG._serialized_end=4190
  _CLOUDBUILDTRIGGER._serialized_start=4193
  _CLOUDBUILDTRIGGER._serialized_end=5411
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._serialized_start=1710
  _CLOUDBUILDTRIGGER_SUBSTITUTIONSENTRY._serialized_end=1762
  _CLOUDBUILDWORKERPOOLXNETWORKCONFIG._serialized_start=5413
  _CLOUDBUILDWORKERPOOLXNETWORKCONFIG._serialized_end=5473
  _CLOUDBUILDWORKERPOOLXTIMEOUTS._serialized_start=5475
  _CLOUDBUILDWORKERPOOLXTIMEOUTS._serialized_end=5554
  _CLOUDBUILDWORKERPOOLXWORKERCONFIG._serialized_start=5556
  _CLOUDBUILDWORKERPOOLXWORKERCONFIG._serialized_end=5659
  _CLOUDBUILDWORKERPOOL._serialized_start=5662
  _CLOUDBUILDWORKERPOOL._serialized_end=6306
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._serialized_start=6256
  _CLOUDBUILDWORKERPOOL_ANNOTATIONSENTRY._serialized_end=6306
# @@protoc_insertion_point(module_scope)
